@@ -4,11 +4,11 @@
 #define R__NO_DEPRECATION
 
 /*******************************************************************/
-#include <stddef.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <assert.h>
+#include <cstddef>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
+#include <cassert>
 #define G__DICTIONARY
 #include "ROOT/RConfig.hxx"
 #include "TClass.h"
@@ -51,7 +51,6 @@
 #include "TThread.h"
 #include "TThreadImp.h"
 #include "TThreadPool.h"
-#include "ROOT/RConcurrentHashColl.hxx"
 #include "ROOT/TRWSpinLock.hxx"
 #include "ROOT/TSpinMutex.hxx"
 #include "ROOT/TThreadedObject.hxx"
@@ -1479,7 +1478,6 @@ namespace {
 "TThread.h",
 "TThreadImp.h",
 "TThreadPool.h",
-"ROOT/RConcurrentHashColl.hxx",
 "ROOT/TRWSpinLock.hxx",
 "ROOT/TSpinMutex.hxx",
 "ROOT/TThreadedObject.hxx",
@@ -1488,7 +1486,6 @@ nullptr
     static const char* includePaths[] = {
 "/build/root/src/build-cuda/include",
 "/usr/include",
-"/usr/include",
 "/build/root/src/build-cuda/include",
 nullptr
     };
