@@ -4,11 +4,11 @@
 #define R__NO_DEPRECATION
 
 /*******************************************************************/
-#include <stddef.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <assert.h>
+#include <cstddef>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
+#include <cassert>
 #define G__DICTIONARY
 #include "ROOT/RConfig.hxx"
 #include "TClass.h"
@@ -543,21 +543,23 @@ nullptr
     static const char* includePaths[] = {
 "/build/root/src/build-cuda/include",
 "/usr/include",
-"/usr/include",
 "/build/root/src/build-cuda/include/",
 nullptr
     };
     static const char* fwdDeclCode = R"DICTFWDDCLS(
 #line 1 "libGviz3d dictionary forward declarations' payload"
+
+#pragma diagnostic push
 #pragma clang diagnostic ignored "-Wkeyword-compat"
 #pragma clang diagnostic ignored "-Wignored-attributes"
 #pragma clang diagnostic ignored "-Wreturn-type-c-linkage"
 extern int __Cling_AutoLoading_Map;
-class __attribute__((annotate("$clingAutoload$TStructNode.h")))  TStructNode;
-class __attribute__((annotate("$clingAutoload$TStructNodeEditor.h")))  TStructNodeEditor;
-class __attribute__((annotate("$clingAutoload$TStructNodeProperty.h")))  TStructNodeProperty;
-class __attribute__((annotate("$clingAutoload$TStructViewer.h")))  TStructViewer;
-class __attribute__((annotate("$clingAutoload$TStructViewerGUI.h")))  TStructViewerGUI;
+class  __attribute__((annotate("$clingAutoload$TStructNode.h")))  TStructNode;
+class  __attribute__((annotate("$clingAutoload$TStructNodeEditor.h")))  TStructNodeEditor;
+class  __attribute__((annotate("$clingAutoload$TStructNodeProperty.h")))  TStructNodeProperty;
+class  __attribute__((annotate("$clingAutoload$TStructViewer.h")))  TStructViewer;
+class  __attribute__((annotate("$clingAutoload$TStructViewerGUI.h")))  TStructViewerGUI;
+#pragma diagnostic pop
 )DICTFWDDCLS";
     static const char* payloadCode = R"DICTPAYLOAD(
 #line 1 "libGviz3d dictionary payload"
@@ -565,6 +567,12 @@ class __attribute__((annotate("$clingAutoload$TStructViewerGUI.h")))  TStructVie
 #ifndef ROOT_SUPPORT_CLAD
   #define ROOT_SUPPORT_CLAD 1
 #endif
+#ifndef _ROOT_GL_BUILDS_ITSELF
+  #define _ROOT_GL_BUILDS_ITSELF 1
+#endif
+#ifndef R__DUMMY_CXX_STANDARD_17
+  #define R__DUMMY_CXX_STANDARD_17 1
+#endif
 
 #define _BACKWARD_BACKWARD_WARNING_H
 // Inline headers
