@@ -4,11 +4,11 @@
 #define R__NO_DEPRECATION
 
 /*******************************************************************/
-#include <stddef.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <assert.h>
+#include <cstddef>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
+#include <cassert>
 #define G__DICTIONARY
 #include "ROOT/RConfig.hxx"
 #include "TClass.h"
@@ -51,6 +51,7 @@
 #include "ROOT/Browsable/TObjectElement.hxx"
 #include "ROOT/Browsable/TObjectHolder.hxx"
 #include "ROOT/Browsable/TObjectItem.hxx"
+#include "ROOT/Browsable/RNTupleItem.hxx"
 
 // Header files passed via #pragma extra_include
 
@@ -643,6 +644,51 @@ namespace ROOT {
 
 } // end of namespace ROOT
 
+namespace ROOT {
+   static TClass *ROOTcLcLBrowsablecLcLRNTupleItem_Dictionary();
+   static void ROOTcLcLBrowsablecLcLRNTupleItem_TClassManip(TClass*);
+   static void *new_ROOTcLcLBrowsablecLcLRNTupleItem(void *p = nullptr);
+   static void *newArray_ROOTcLcLBrowsablecLcLRNTupleItem(Long_t size, void *p);
+   static void delete_ROOTcLcLBrowsablecLcLRNTupleItem(void *p);
+   static void deleteArray_ROOTcLcLBrowsablecLcLRNTupleItem(void *p);
+   static void destruct_ROOTcLcLBrowsablecLcLRNTupleItem(void *p);
+
+   // Function generating the singleton type initializer
+   static TGenericClassInfo *GenerateInitInstanceLocal(const ::ROOT::Browsable::RNTupleItem*)
+   {
+      ::ROOT::Browsable::RNTupleItem *ptr = nullptr;
+      static ::TVirtualIsAProxy* isa_proxy = new ::TIsAProxy(typeid(::ROOT::Browsable::RNTupleItem));
+      static ::ROOT::TGenericClassInfo 
+         instance("ROOT::Browsable::RNTupleItem", "ROOT/Browsable/RNTupleItem.hxx", 23,
+                  typeid(::ROOT::Browsable::RNTupleItem), ::ROOT::Internal::DefineBehavior(ptr, ptr),
+                  &ROOTcLcLBrowsablecLcLRNTupleItem_Dictionary, isa_proxy, 4,
+                  sizeof(::ROOT::Browsable::RNTupleItem) );
+      instance.SetNew(&new_ROOTcLcLBrowsablecLcLRNTupleItem);
+      instance.SetNewArray(&newArray_ROOTcLcLBrowsablecLcLRNTupleItem);
+      instance.SetDelete(&delete_ROOTcLcLBrowsablecLcLRNTupleItem);
+      instance.SetDeleteArray(&deleteArray_ROOTcLcLBrowsablecLcLRNTupleItem);
+      instance.SetDestructor(&destruct_ROOTcLcLBrowsablecLcLRNTupleItem);
+      return &instance;
+   }
+   TGenericClassInfo *GenerateInitInstance(const ::ROOT::Browsable::RNTupleItem*)
+   {
+      return GenerateInitInstanceLocal(static_cast<::ROOT::Browsable::RNTupleItem*>(nullptr));
+   }
+   // Static variable to force the class initialization
+   static ::ROOT::TGenericClassInfo *_R__UNIQUE_DICT_(Init) = GenerateInitInstanceLocal(static_cast<const ::ROOT::Browsable::RNTupleItem*>(nullptr)); R__UseDummy(_R__UNIQUE_DICT_(Init));
+
+   // Dictionary for non-ClassDef classes
+   static TClass *ROOTcLcLBrowsablecLcLRNTupleItem_Dictionary() {
+      TClass* theClass =::ROOT::GenerateInitInstanceLocal(static_cast<const ::ROOT::Browsable::RNTupleItem*>(nullptr))->GetClass();
+      ROOTcLcLBrowsablecLcLRNTupleItem_TClassManip(theClass);
+   return theClass;
+   }
+
+   static void ROOTcLcLBrowsablecLcLRNTupleItem_TClassManip(TClass* ){
+   }
+
+} // end of namespace ROOT
+
 namespace ROOT {
    // Wrapper around operator delete
    static void delete_ROOTcLcLBrowsablecLcLRHolder(void *p) {
@@ -867,6 +913,27 @@ namespace ROOT {
    }
 } // end of namespace ROOT for class ::ROOT::Browsable::TObjectItem
 
+namespace ROOT {
+   // Wrappers around operator new
+   static void *new_ROOTcLcLBrowsablecLcLRNTupleItem(void *p) {
+      return  p ? ::new(static_cast<::ROOT::Internal::TOperatorNewHelper*>(p)) ::ROOT::Browsable::RNTupleItem : new ::ROOT::Browsable::RNTupleItem;
+   }
+   static void *newArray_ROOTcLcLBrowsablecLcLRNTupleItem(Long_t nElements, void *p) {
+      return p ? ::new(static_cast<::ROOT::Internal::TOperatorNewHelper*>(p)) ::ROOT::Browsable::RNTupleItem[nElements] : new ::ROOT::Browsable::RNTupleItem[nElements];
+   }
+   // Wrapper around operator delete
+   static void delete_ROOTcLcLBrowsablecLcLRNTupleItem(void *p) {
+      delete (static_cast<::ROOT::Browsable::RNTupleItem*>(p));
+   }
+   static void deleteArray_ROOTcLcLBrowsablecLcLRNTupleItem(void *p) {
+      delete [] (static_cast<::ROOT::Browsable::RNTupleItem*>(p));
+   }
+   static void destruct_ROOTcLcLBrowsablecLcLRNTupleItem(void *p) {
+      typedef ::ROOT::Browsable::RNTupleItem current_t;
+      (static_cast<current_t*>(p))->~current_t();
+   }
+} // end of namespace ROOT for class ::ROOT::Browsable::RNTupleItem
+
 namespace ROOT {
    static TClass *vectorlEshared_ptrlEROOTcLcLBrowsablecLcLRElementgRsPgR_Dictionary();
    static void vectorlEshared_ptrlEROOTcLcLBrowsablecLcLRElementgRsPgR_TClassManip(TClass*);
@@ -958,34 +1025,38 @@ namespace {
 "ROOT/Browsable/TObjectElement.hxx",
 "ROOT/Browsable/TObjectHolder.hxx",
 "ROOT/Browsable/TObjectItem.hxx",
+"ROOT/Browsable/RNTupleItem.hxx",
 nullptr
     };
     static const char* includePaths[] = {
 "/build/root/src/build-cuda/include",
 "/usr/include",
-"/usr/include",
 "/build/root/src/build-cuda/include/",
 nullptr
     };
     static const char* fwdDeclCode = R"DICTFWDDCLS(
 #line 1 "libROOTBrowsable dictionary forward declarations' payload"
+
+#pragma diagnostic push
 #pragma clang diagnostic ignored "-Wkeyword-compat"
 #pragma clang diagnostic ignored "-Wignored-attributes"
 #pragma clang diagnostic ignored "-Wreturn-type-c-linkage"
 extern int __Cling_AutoLoading_Map;
-namespace ROOT{namespace Browsable{class __attribute__((annotate("$clingAutoload$ROOT/Browsable/RHolder.hxx")))  __attribute__((annotate("$clingAutoload$ROOT/Browsable/RAnyObjectHolder.hxx")))  RHolder;}}
-namespace ROOT{namespace Browsable{class __attribute__((annotate("$clingAutoload$ROOT/Browsable/RAnyObjectHolder.hxx")))  RAnyObjectHolder;}}
-namespace ROOT{namespace Browsable{class __attribute__((annotate("$clingAutoload$ROOT/Browsable/RElement.hxx")))  RElement;}}
-namespace ROOT{namespace Browsable{class __attribute__((annotate("$clingAutoload$ROOT/Browsable/RGroup.hxx")))  RGroup;}}
-namespace ROOT{namespace Browsable{class __attribute__((annotate("$clingAutoload$ROOT/Browsable/RItem.hxx")))  RItem;}}
-namespace ROOT{namespace Browsable{class __attribute__((annotate("$clingAutoload$ROOT/Browsable/RLevelIter.hxx")))  RLevelIter;}}
-namespace ROOT{namespace Browsable{class __attribute__((annotate("$clingAutoload$ROOT/Browsable/RProvider.hxx")))  RProvider;}}
-namespace ROOT{namespace Browsable{class __attribute__((annotate("$clingAutoload$ROOT/Browsable/RSysFile.hxx")))  RSysFile;}}
-namespace ROOT{namespace Browsable{class __attribute__((annotate("$clingAutoload$ROOT/Browsable/RSysFileItem.hxx")))  RSysFileItem;}}
-namespace ROOT{namespace Browsable{class __attribute__((annotate("$clingAutoload$ROOT/Browsable/RWrapper.hxx")))  RWrapper;}}
-namespace ROOT{namespace Browsable{class __attribute__((annotate("$clingAutoload$ROOT/Browsable/TKeyItem.hxx")))  TKeyItem;}}
-namespace ROOT{namespace Browsable{class __attribute__((annotate("$clingAutoload$ROOT/Browsable/TObjectHolder.hxx")))  TObjectHolder;}}
-namespace ROOT{namespace Browsable{class __attribute__((annotate("$clingAutoload$ROOT/Browsable/TObjectItem.hxx")))  TObjectItem;}}
+namespace ROOT{namespace Browsable{class  __attribute__((annotate("$clingAutoload$ROOT/Browsable/RHolder.hxx")))  __attribute__((annotate("$clingAutoload$ROOT/Browsable/RAnyObjectHolder.hxx")))  RHolder;}}
+namespace ROOT{namespace Browsable{class  __attribute__((annotate("$clingAutoload$ROOT/Browsable/RAnyObjectHolder.hxx")))  RAnyObjectHolder;}}
+namespace ROOT{namespace Browsable{class  __attribute__((annotate("$clingAutoload$ROOT/Browsable/RElement.hxx")))  RElement;}}
+namespace ROOT{namespace Browsable{class  __attribute__((annotate("$clingAutoload$ROOT/Browsable/RGroup.hxx")))  RGroup;}}
+namespace ROOT{namespace Browsable{class  __attribute__((annotate("$clingAutoload$ROOT/Browsable/RItem.hxx")))  RItem;}}
+namespace ROOT{namespace Browsable{class  __attribute__((annotate("$clingAutoload$ROOT/Browsable/RLevelIter.hxx")))  RLevelIter;}}
+namespace ROOT{namespace Browsable{class  __attribute__((annotate("$clingAutoload$ROOT/Browsable/RProvider.hxx")))  RProvider;}}
+namespace ROOT{namespace Browsable{class  __attribute__((annotate("$clingAutoload$ROOT/Browsable/RSysFile.hxx")))  RSysFile;}}
+namespace ROOT{namespace Browsable{class  __attribute__((annotate("$clingAutoload$ROOT/Browsable/RSysFileItem.hxx")))  RSysFileItem;}}
+namespace ROOT{namespace Browsable{class  __attribute__((annotate("$clingAutoload$ROOT/Browsable/RWrapper.hxx")))  RWrapper;}}
+namespace ROOT{namespace Browsable{class  __attribute__((annotate("$clingAutoload$ROOT/Browsable/TKeyItem.hxx")))  TKeyItem;}}
+namespace ROOT{namespace Browsable{class  __attribute__((annotate("$clingAutoload$ROOT/Browsable/TObjectHolder.hxx")))  TObjectHolder;}}
+namespace ROOT{namespace Browsable{class  __attribute__((annotate("$clingAutoload$ROOT/Browsable/TObjectItem.hxx")))  TObjectItem;}}
+namespace ROOT{namespace Browsable{class  __attribute__((annotate("$clingAutoload$ROOT/Browsable/RNTupleItem.hxx")))  RNTupleItem;}}
+#pragma diagnostic pop
 )DICTFWDDCLS";
     static const char* payloadCode = R"DICTPAYLOAD(
 #line 1 "libROOTBrowsable dictionary payload"
@@ -993,6 +1064,9 @@ namespace ROOT{namespace Browsable{class __attribute__((annotate("$clingAutoload
 #ifndef ROOT_SUPPORT_CLAD
   #define ROOT_SUPPORT_CLAD 1
 #endif
+#ifndef R__DUMMY_CXX_STANDARD_17
+  #define R__DUMMY_CXX_STANDARD_17 1
+#endif
 
 #define _BACKWARD_BACKWARD_WARNING_H
 // Inline headers
@@ -1012,6 +1086,7 @@ namespace ROOT{namespace Browsable{class __attribute__((annotate("$clingAutoload
 #include "ROOT/Browsable/TObjectElement.hxx"
 #include "ROOT/Browsable/TObjectHolder.hxx"
 #include "ROOT/Browsable/TObjectItem.hxx"
+#include "ROOT/Browsable/RNTupleItem.hxx"
 
 #undef  _BACKWARD_BACKWARD_WARNING_H
 )DICTPAYLOAD";
@@ -1022,6 +1097,7 @@ namespace ROOT{namespace Browsable{class __attribute__((annotate("$clingAutoload
 "ROOT::Browsable::RHolder", payloadCode, "@",
 "ROOT::Browsable::RItem", payloadCode, "@",
 "ROOT::Browsable::RLevelIter", payloadCode, "@",
+"ROOT::Browsable::RNTupleItem", payloadCode, "@",
 "ROOT::Browsable::RProvider", payloadCode, "@",
 "ROOT::Browsable::RSysFile", payloadCode, "@",
 "ROOT::Browsable::RSysFileItem", payloadCode, "@",
