@@ -4,11 +4,11 @@
 #define R__NO_DEPRECATION
 
 /*******************************************************************/
-#include <stddef.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <assert.h>
+#include <cstddef>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
+#include <cassert>
 #define G__DICTIONARY
 #include "ROOT/RConfig.hxx"
 #include "TClass.h"
@@ -95,7 +95,7 @@ namespace ROOT {
       ::TGraphPainter *ptr = nullptr;
       static ::TVirtualIsAProxy* isa_proxy = new ::TInstrumentedIsAProxy< ::TGraphPainter >(nullptr);
       static ::ROOT::TGenericClassInfo 
-         instance("TGraphPainter", ::TGraphPainter::Class_Version(), "TGraphPainter.h", 31,
+         instance("TGraphPainter", ::TGraphPainter::Class_Version(), "TGraphPainter.h", 32,
                   typeid(::TGraphPainter), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                   &::TGraphPainter::Dictionary, isa_proxy, 16,
                   sizeof(::TGraphPainter) );
@@ -474,7 +474,6 @@ nullptr
     static const char* includePaths[] = {
 "/build/root/src/build-cuda/include",
 "/usr/include",
-"/usr/include",
 "/build/root/src/build-cuda/include/",
 nullptr
     };
