@@ -4,11 +4,11 @@
 #define R__NO_DEPRECATION
 
 /*******************************************************************/
-#include <stddef.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <assert.h>
+#include <cstddef>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
+#include <cassert>
 #define G__DICTIONARY
 #include "ROOT/RConfig.hxx"
 #include "TClass.h"
@@ -1248,31 +1248,36 @@ nullptr
     static const char* includePaths[] = {
 "/build/root/src/build-cuda/include",
 "/usr/include",
-"/usr/include",
 "/build/root/src/build-cuda/include/",
 nullptr
     };
     static const char* fwdDeclCode = R"DICTFWDDCLS(
 #line 1 "libSQLIO dictionary forward declarations' payload"
+
+#pragma diagnostic push
 #pragma clang diagnostic ignored "-Wkeyword-compat"
 #pragma clang diagnostic ignored "-Wignored-attributes"
 #pragma clang diagnostic ignored "-Wreturn-type-c-linkage"
 extern int __Cling_AutoLoading_Map;
-class __attribute__((annotate("$clingAutoload$TBufferSQL2.h")))  TBufferSQL2;
-class __attribute__((annotate("$clingAutoload$TKeySQL.h")))  TKeySQL;
-class __attribute__((annotate("$clingAutoload$TSQLClassInfo.h")))  TSQLClassColumnInfo;
-class __attribute__((annotate("$clingAutoload$TSQLClassInfo.h")))  TSQLClassInfo;
-class __attribute__((annotate("$clingAutoload$TSQLFile.h")))  TSQLFile;
-class __attribute__((annotate("$clingAutoload$TSQLObjectData.h")))  TSQLObjectInfo;
-class __attribute__((annotate("$clingAutoload$TSQLObjectData.h")))  TSQLObjectData;
-class __attribute__((annotate("$clingAutoload$TSQLObjectData.h")))  TSQLObjectDataPool;
-class __attribute__((annotate("$clingAutoload$TSQLStructure.h")))  TSQLColumnData;
-class __attribute__((annotate("$clingAutoload$TSQLStructure.h")))  TSQLTableData;
-class __attribute__((annotate("$clingAutoload$TSQLStructure.h")))  TSQLStructure;
+class  __attribute__((annotate("$clingAutoload$TBufferSQL2.h")))  TBufferSQL2;
+class  __attribute__((annotate("$clingAutoload$TKeySQL.h")))  TKeySQL;
+class  __attribute__((annotate("$clingAutoload$TSQLClassInfo.h")))  TSQLClassColumnInfo;
+class  __attribute__((annotate("$clingAutoload$TSQLClassInfo.h")))  TSQLClassInfo;
+class  __attribute__((annotate("$clingAutoload$TSQLFile.h")))  TSQLFile;
+class  __attribute__((annotate("$clingAutoload$TSQLObjectData.h")))  TSQLObjectInfo;
+class  __attribute__((annotate("$clingAutoload$TSQLObjectData.h")))  TSQLObjectData;
+class  __attribute__((annotate("$clingAutoload$TSQLObjectData.h")))  TSQLObjectDataPool;
+class  __attribute__((annotate("$clingAutoload$TSQLStructure.h")))  TSQLColumnData;
+class  __attribute__((annotate("$clingAutoload$TSQLStructure.h")))  TSQLTableData;
+class  __attribute__((annotate("$clingAutoload$TSQLStructure.h")))  TSQLStructure;
+#pragma diagnostic pop
 )DICTFWDDCLS";
     static const char* payloadCode = R"DICTPAYLOAD(
 #line 1 "libSQLIO dictionary payload"
 
+#ifndef R__DUMMY_CXX_STANDARD_17
+  #define R__DUMMY_CXX_STANDARD_17 1
+#endif
 
 #define _BACKWARD_BACKWARD_WARNING_H
 // Inline headers
