@@ -4,11 +4,11 @@
 #define R__NO_DEPRECATION
 
 /*******************************************************************/
-#include <stddef.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <assert.h>
+#include <cstddef>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
+#include <cassert>
 #define G__DICTIONARY
 #include "ROOT/RConfig.hxx"
 #include "TClass.h"
@@ -1440,34 +1440,39 @@ nullptr
     static const char* includePaths[] = {
 "/build/root/src/build-cuda/include",
 "/usr/include",
-"/usr/include",
 "/build/root/src/build-cuda/include/",
 nullptr
     };
     static const char* fwdDeclCode = R"DICTFWDDCLS(
 #line 1 "libQuadp dictionary forward declarations' payload"
+
+#pragma diagnostic push
 #pragma clang diagnostic ignored "-Wkeyword-compat"
 #pragma clang diagnostic ignored "-Wignored-attributes"
 #pragma clang diagnostic ignored "-Wreturn-type-c-linkage"
 extern int __Cling_AutoLoading_Map;
-class __attribute__((annotate("$clingAutoload$TQpVar.h")))  __attribute__((annotate("$clingAutoload$TGondzioSolver.h")))  TQpVar;
-class __attribute__((annotate("$clingAutoload$TQpDataBase.h")))  __attribute__((annotate("$clingAutoload$TGondzioSolver.h")))  TQpDataBase;
-class __attribute__((annotate("$clingAutoload$TQpDataDens.h")))  __attribute__((annotate("$clingAutoload$TGondzioSolver.h")))  TQpDataDens;
-class __attribute__((annotate("$clingAutoload$TQpResidual.h")))  __attribute__((annotate("$clingAutoload$TGondzioSolver.h")))  TQpResidual;
-class __attribute__((annotate("$clingAutoload$TQpProbBase.h")))  __attribute__((annotate("$clingAutoload$TGondzioSolver.h")))  TQpProbBase;
-class __attribute__((annotate("$clingAutoload$TQpLinSolverBase.h")))  __attribute__((annotate("$clingAutoload$TGondzioSolver.h")))  TQpLinSolverBase;
-class __attribute__((annotate("$clingAutoload$TQpSolverBase.h")))  __attribute__((annotate("$clingAutoload$TGondzioSolver.h")))  TQpSolverBase;
-class __attribute__((annotate("$clingAutoload$TGondzioSolver.h")))  TGondzioSolver;
-class __attribute__((annotate("$clingAutoload$TMehrotraSolver.h")))  TMehrotraSolver;
-class __attribute__((annotate("$clingAutoload$TQpDataSparse.h")))  TQpDataSparse;
-class __attribute__((annotate("$clingAutoload$TQpProbDens.h")))  __attribute__((annotate("$clingAutoload$TQpLinSolverDens.h")))  TQpProbDens;
-class __attribute__((annotate("$clingAutoload$TQpLinSolverDens.h")))  TQpLinSolverDens;
-class __attribute__((annotate("$clingAutoload$TQpProbSparse.h")))  __attribute__((annotate("$clingAutoload$TQpLinSolverSparse.h")))  TQpProbSparse;
-class __attribute__((annotate("$clingAutoload$TQpLinSolverSparse.h")))  TQpLinSolverSparse;
+class  __attribute__((annotate("$clingAutoload$TQpVar.h")))  __attribute__((annotate("$clingAutoload$TGondzioSolver.h")))  TQpVar;
+class  __attribute__((annotate("$clingAutoload$TQpDataBase.h")))  __attribute__((annotate("$clingAutoload$TGondzioSolver.h")))  TQpDataBase;
+class  __attribute__((annotate("$clingAutoload$TQpDataDens.h")))  __attribute__((annotate("$clingAutoload$TGondzioSolver.h")))  TQpDataDens;
+class  __attribute__((annotate("$clingAutoload$TQpResidual.h")))  __attribute__((annotate("$clingAutoload$TGondzioSolver.h")))  TQpResidual;
+class  __attribute__((annotate("$clingAutoload$TQpProbBase.h")))  __attribute__((annotate("$clingAutoload$TGondzioSolver.h")))  TQpProbBase;
+class  __attribute__((annotate("$clingAutoload$TQpLinSolverBase.h")))  __attribute__((annotate("$clingAutoload$TGondzioSolver.h")))  TQpLinSolverBase;
+class  __attribute__((annotate("$clingAutoload$TQpSolverBase.h")))  __attribute__((annotate("$clingAutoload$TGondzioSolver.h")))  TQpSolverBase;
+class  __attribute__((annotate("$clingAutoload$TGondzioSolver.h")))  TGondzioSolver;
+class  __attribute__((annotate("$clingAutoload$TMehrotraSolver.h")))  TMehrotraSolver;
+class  __attribute__((annotate("$clingAutoload$TQpDataSparse.h")))  TQpDataSparse;
+class  __attribute__((annotate("$clingAutoload$TQpProbDens.h")))  __attribute__((annotate("$clingAutoload$TQpLinSolverDens.h")))  TQpProbDens;
+class  __attribute__((annotate("$clingAutoload$TQpLinSolverDens.h")))  TQpLinSolverDens;
+class  __attribute__((annotate("$clingAutoload$TQpProbSparse.h")))  __attribute__((annotate("$clingAutoload$TQpLinSolverSparse.h")))  TQpProbSparse;
+class  __attribute__((annotate("$clingAutoload$TQpLinSolverSparse.h")))  TQpLinSolverSparse;
+#pragma diagnostic pop
 )DICTFWDDCLS";
     static const char* payloadCode = R"DICTPAYLOAD(
 #line 1 "libQuadp dictionary payload"
 
+#ifndef R__DUMMY_CXX_STANDARD_17
+  #define R__DUMMY_CXX_STANDARD_17 1
+#endif
 
 #define _BACKWARD_BACKWARD_WARNING_H
 // Inline headers
