@@ -4,11 +4,11 @@
 #define R__NO_DEPRECATION
 
 /*******************************************************************/
-#include <stddef.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <assert.h>
+#include <cstddef>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
+#include <cassert>
 #define G__DICTIONARY
 #include "ROOT/RConfig.hxx"
 #include "TClass.h"
@@ -52,7 +52,7 @@ namespace ROOT {
       inline ::ROOT::TGenericClassInfo *GenerateInitInstance()
       {
          static ::ROOT::TGenericClassInfo 
-            instance("ROOT::VecOps", 0 /*version*/, "ROOT/RVec.hxx", 61,
+            instance("ROOT::VecOps", 0 /*version*/, "ROOT/RVec.hxx", 62,
                      ::ROOT::Internal::DefineBehavior((void*)nullptr,(void*)nullptr),
                      &ROOTcLcLVecOps_Dictionary, 0);
          return &instance;
@@ -84,7 +84,7 @@ namespace ROOT {
       ::ROOT::Internal::VecOps::SmallVectorBase *ptr = nullptr;
       static ::TVirtualIsAProxy* isa_proxy = new ::TIsAProxy(typeid(::ROOT::Internal::VecOps::SmallVectorBase));
       static ::ROOT::TGenericClassInfo 
-         instance("ROOT::Internal::VecOps::SmallVectorBase", "ROOT/RVec.hxx", 139,
+         instance("ROOT::Internal::VecOps::SmallVectorBase", "ROOT/RVec.hxx", 140,
                   typeid(::ROOT::Internal::VecOps::SmallVectorBase), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                   &ROOTcLcLInternalcLcLVecOpscLcLSmallVectorBase_Dictionary, isa_proxy, 1,
                   sizeof(::ROOT::Internal::VecOps::SmallVectorBase) );
@@ -141,7 +141,7 @@ namespace ROOT {
       ROOT::VecOps::RVec<unsigned short> *ptr = nullptr;
       static ::TVirtualIsAProxy* isa_proxy = new ::TIsAProxy(typeid(ROOT::VecOps::RVec<unsigned short>));
       static ::ROOT::TGenericClassInfo 
-         instance("ROOT::VecOps::RVec<unsigned short>", -2, "ROOT/RVec.hxx", 3419,
+         instance("ROOT::VecOps::RVec<unsigned short>", -2, "ROOT/RVec.hxx", 3685,
                   typeid(ROOT::VecOps::RVec<unsigned short>), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                   &ROOTcLcLVecOpscLcLRVeclEunsignedsPshortgR_Dictionary, isa_proxy, 4,
                   sizeof(ROOT::VecOps::RVec<unsigned short>) );
@@ -208,7 +208,7 @@ namespace ROOT {
       ROOT::VecOps::RVec<unsigned long> *ptr = nullptr;
       static ::TVirtualIsAProxy* isa_proxy = new ::TIsAProxy(typeid(ROOT::VecOps::RVec<unsigned long>));
       static ::ROOT::TGenericClassInfo 
-         instance("ROOT::VecOps::RVec<unsigned long>", -2, "ROOT/RVec.hxx", 3421,
+         instance("ROOT::VecOps::RVec<unsigned long>", -2, "ROOT/RVec.hxx", 3687,
                   typeid(ROOT::VecOps::RVec<unsigned long>), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                   &ROOTcLcLVecOpscLcLRVeclEunsignedsPlonggR_Dictionary, isa_proxy, 4,
                   sizeof(ROOT::VecOps::RVec<unsigned long>) );
@@ -275,7 +275,7 @@ namespace ROOT {
       ROOT::VecOps::RVec<unsigned int> *ptr = nullptr;
       static ::TVirtualIsAProxy* isa_proxy = new ::TIsAProxy(typeid(ROOT::VecOps::RVec<unsigned int>));
       static ::ROOT::TGenericClassInfo 
-         instance("ROOT::VecOps::RVec<unsigned int>", -2, "ROOT/RVec.hxx", 3420,
+         instance("ROOT::VecOps::RVec<unsigned int>", -2, "ROOT/RVec.hxx", 3686,
                   typeid(ROOT::VecOps::RVec<unsigned int>), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                   &ROOTcLcLVecOpscLcLRVeclEunsignedsPintgR_Dictionary, isa_proxy, 4,
                   sizeof(ROOT::VecOps::RVec<unsigned int>) );
@@ -342,7 +342,7 @@ namespace ROOT {
       ROOT::VecOps::RVec<unsigned char> *ptr = nullptr;
       static ::TVirtualIsAProxy* isa_proxy = new ::TIsAProxy(typeid(ROOT::VecOps::RVec<unsigned char>));
       static ::ROOT::TGenericClassInfo 
-         instance("ROOT::VecOps::RVec<unsigned char>", -2, "ROOT/RVec.hxx", 3418,
+         instance("ROOT::VecOps::RVec<unsigned char>", -2, "ROOT/RVec.hxx", 3684,
                   typeid(ROOT::VecOps::RVec<unsigned char>), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                   &ROOTcLcLVecOpscLcLRVeclEunsignedsPchargR_Dictionary, isa_proxy, 4,
                   sizeof(ROOT::VecOps::RVec<unsigned char>) );
@@ -409,7 +409,7 @@ namespace ROOT {
       ROOT::VecOps::RVec<string> *ptr = nullptr;
       static ::TVirtualIsAProxy* isa_proxy = new ::TIsAProxy(typeid(ROOT::VecOps::RVec<string>));
       static ::ROOT::TGenericClassInfo 
-         instance("ROOT::VecOps::RVec<string>", -2, "ROOT/RVec.hxx", 1530,
+         instance("ROOT::VecOps::RVec<string>", -2, "ROOT/RVec.hxx", 1526,
                   typeid(ROOT::VecOps::RVec<string>), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                   &ROOTcLcLVecOpscLcLRVeclEstringgR_Dictionary, isa_proxy, 4,
                   sizeof(ROOT::VecOps::RVec<string>) );
@@ -478,7 +478,7 @@ namespace ROOT {
       ROOT::VecOps::RVec<short> *ptr = nullptr;
       static ::TVirtualIsAProxy* isa_proxy = new ::TIsAProxy(typeid(ROOT::VecOps::RVec<short>));
       static ::ROOT::TGenericClassInfo 
-         instance("ROOT::VecOps::RVec<short>", -2, "ROOT/RVec.hxx", 3413,
+         instance("ROOT::VecOps::RVec<short>", -2, "ROOT/RVec.hxx", 3679,
                   typeid(ROOT::VecOps::RVec<short>), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                   &ROOTcLcLVecOpscLcLRVeclEshortgR_Dictionary, isa_proxy, 4,
                   sizeof(ROOT::VecOps::RVec<short>) );
@@ -545,7 +545,7 @@ namespace ROOT {
       ROOT::VecOps::RVec<long> *ptr = nullptr;
       static ::TVirtualIsAProxy* isa_proxy = new ::TIsAProxy(typeid(ROOT::VecOps::RVec<long>));
       static ::ROOT::TGenericClassInfo 
-         instance("ROOT::VecOps::RVec<long>", -2, "ROOT/RVec.hxx", 3415,
+         instance("ROOT::VecOps::RVec<long>", -2, "ROOT/RVec.hxx", 3681,
                   typeid(ROOT::VecOps::RVec<long>), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                   &ROOTcLcLVecOpscLcLRVeclElonggR_Dictionary, isa_proxy, 4,
                   sizeof(ROOT::VecOps::RVec<long>) );
@@ -612,7 +612,7 @@ namespace ROOT {
       ROOT::VecOps::RVec<int> *ptr = nullptr;
       static ::TVirtualIsAProxy* isa_proxy = new ::TIsAProxy(typeid(ROOT::VecOps::RVec<int>));
       static ::ROOT::TGenericClassInfo 
-         instance("ROOT::VecOps::RVec<int>", -2, "ROOT/RVec.hxx", 3414,
+         instance("ROOT::VecOps::RVec<int>", -2, "ROOT/RVec.hxx", 3680,
                   typeid(ROOT::VecOps::RVec<int>), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                   &ROOTcLcLVecOpscLcLRVeclEintgR_Dictionary, isa_proxy, 4,
                   sizeof(ROOT::VecOps::RVec<int>) );
@@ -679,7 +679,7 @@ namespace ROOT {
       ROOT::VecOps::RVec<float> *ptr = nullptr;
       static ::TVirtualIsAProxy* isa_proxy = new ::TIsAProxy(typeid(ROOT::VecOps::RVec<float>));
       static ::ROOT::TGenericClassInfo 
-         instance("ROOT::VecOps::RVec<float>", -2, "ROOT/RVec.hxx", 3424,
+         instance("ROOT::VecOps::RVec<float>", -2, "ROOT/RVec.hxx", 3690,
                   typeid(ROOT::VecOps::RVec<float>), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                   &ROOTcLcLVecOpscLcLRVeclEfloatgR_Dictionary, isa_proxy, 4,
                   sizeof(ROOT::VecOps::RVec<float>) );
@@ -746,7 +746,7 @@ namespace ROOT {
       ROOT::VecOps::RVec<double> *ptr = nullptr;
       static ::TVirtualIsAProxy* isa_proxy = new ::TIsAProxy(typeid(ROOT::VecOps::RVec<double>));
       static ::ROOT::TGenericClassInfo 
-         instance("ROOT::VecOps::RVec<double>", -2, "ROOT/RVec.hxx", 3425,
+         instance("ROOT::VecOps::RVec<double>", -2, "ROOT/RVec.hxx", 3691,
                   typeid(ROOT::VecOps::RVec<double>), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                   &ROOTcLcLVecOpscLcLRVeclEdoublegR_Dictionary, isa_proxy, 4,
                   sizeof(ROOT::VecOps::RVec<double>) );
@@ -813,7 +813,7 @@ namespace ROOT {
       ROOT::VecOps::RVec<char> *ptr = nullptr;
       static ::TVirtualIsAProxy* isa_proxy = new ::TIsAProxy(typeid(ROOT::VecOps::RVec<char>));
       static ::ROOT::TGenericClassInfo 
-         instance("ROOT::VecOps::RVec<char>", -2, "ROOT/RVec.hxx", 3412,
+         instance("ROOT::VecOps::RVec<char>", -2, "ROOT/RVec.hxx", 3678,
                   typeid(ROOT::VecOps::RVec<char>), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                   &ROOTcLcLVecOpscLcLRVeclEchargR_Dictionary, isa_proxy, 4,
                   sizeof(ROOT::VecOps::RVec<char>) );
@@ -880,7 +880,7 @@ namespace ROOT {
       ROOT::VecOps::RVec<bool> *ptr = nullptr;
       static ::TVirtualIsAProxy* isa_proxy = new ::TIsAProxy(typeid(ROOT::VecOps::RVec<bool>));
       static ::ROOT::TGenericClassInfo 
-         instance("ROOT::VecOps::RVec<bool>", -2, "ROOT/RVec.hxx", 1530,
+         instance("ROOT::VecOps::RVec<bool>", -2, "ROOT/RVec.hxx", 1526,
                   typeid(ROOT::VecOps::RVec<bool>), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                   &ROOTcLcLVecOpscLcLRVeclEboolgR_Dictionary, isa_proxy, 4,
                   sizeof(ROOT::VecOps::RVec<bool>) );
@@ -947,7 +947,7 @@ namespace ROOT {
       ROOT::VecOps::RVec<ULong64_t> *ptr = nullptr;
       static ::TVirtualIsAProxy* isa_proxy = new ::TIsAProxy(typeid(ROOT::VecOps::RVec<ULong64_t>));
       static ::ROOT::TGenericClassInfo 
-         instance("ROOT::VecOps::RVec<ULong64_t>", -2, "ROOT/RVec.hxx", 1530,
+         instance("ROOT::VecOps::RVec<ULong64_t>", -2, "ROOT/RVec.hxx", 1526,
                   typeid(ROOT::VecOps::RVec<ULong64_t>), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                   &ROOTcLcLVecOpscLcLRVeclEULong64_tgR_Dictionary, isa_proxy, 4,
                   sizeof(ROOT::VecOps::RVec<ULong64_t>) );
@@ -1016,7 +1016,7 @@ namespace ROOT {
       ROOT::VecOps::RVec<Long64_t> *ptr = nullptr;
       static ::TVirtualIsAProxy* isa_proxy = new ::TIsAProxy(typeid(ROOT::VecOps::RVec<Long64_t>));
       static ::ROOT::TGenericClassInfo 
-         instance("ROOT::VecOps::RVec<Long64_t>", -2, "ROOT/RVec.hxx", 1530,
+         instance("ROOT::VecOps::RVec<Long64_t>", -2, "ROOT/RVec.hxx", 1526,
                   typeid(ROOT::VecOps::RVec<Long64_t>), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                   &ROOTcLcLVecOpscLcLRVeclELong64_tgR_Dictionary, isa_proxy, 4,
                   sizeof(ROOT::VecOps::RVec<Long64_t>) );
@@ -1086,7 +1086,6 @@ nullptr
     static const char* includePaths[] = {
 "/build/root/src/build-cuda/include",
 "/usr/include",
-"/usr/include",
 "/build/root/src/build-cuda/include/",
 nullptr
     };
