@@ -4,11 +4,11 @@
 #define R__NO_DEPRECATION
 
 /*******************************************************************/
-#include <stddef.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <assert.h>
+#include <cstddef>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
+#include <cassert>
 #define G__DICTIONARY
 #include "ROOT/RConfig.hxx"
 #include "TClass.h"
@@ -420,24 +420,29 @@ nullptr
     static const char* includePaths[] = {
 "/build/root/src/build-cuda/include",
 "/usr/include",
-"/usr/include",
 "/build/root/src/build-cuda/include/",
 nullptr
     };
     static const char* fwdDeclCode = R"DICTFWDDCLS(
 #line 1 "libRSQLite dictionary forward declarations' payload"
+
+#pragma diagnostic push
 #pragma clang diagnostic ignored "-Wkeyword-compat"
 #pragma clang diagnostic ignored "-Wignored-attributes"
 #pragma clang diagnostic ignored "-Wreturn-type-c-linkage"
 extern int __Cling_AutoLoading_Map;
-class __attribute__((annotate("$clingAutoload$TSQLiteResult.h")))  TSQLiteResult;
-class __attribute__((annotate("$clingAutoload$TSQLiteRow.h")))  TSQLiteRow;
-class __attribute__((annotate("$clingAutoload$TSQLiteServer.h")))  TSQLiteServer;
-class __attribute__((annotate("$clingAutoload$TSQLiteStatement.h")))  TSQLiteStatement;
+class  __attribute__((annotate("$clingAutoload$TSQLiteResult.h")))  TSQLiteResult;
+class  __attribute__((annotate("$clingAutoload$TSQLiteRow.h")))  TSQLiteRow;
+class  __attribute__((annotate("$clingAutoload$TSQLiteServer.h")))  TSQLiteServer;
+class  __attribute__((annotate("$clingAutoload$TSQLiteStatement.h")))  TSQLiteStatement;
+#pragma diagnostic pop
 )DICTFWDDCLS";
     static const char* payloadCode = R"DICTPAYLOAD(
 #line 1 "libRSQLite dictionary payload"
 
+#ifndef R__DUMMY_CXX_STANDARD_17
+  #define R__DUMMY_CXX_STANDARD_17 1
+#endif
 
 #define _BACKWARD_BACKWARD_WARNING_H
 // Inline headers
