@@ -4,11 +4,11 @@
 #define R__NO_DEPRECATION
 
 /*******************************************************************/
-#include <stddef.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <assert.h>
+#include <cstddef>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
+#include <cassert>
 #define G__DICTIONARY
 #include "ROOT/RConfig.hxx"
 #include "TClass.h"
@@ -141,7 +141,7 @@ namespace ROOT {
       ::TMVA::Experimental::SOFIE::Dim *ptr = nullptr;
       static ::TVirtualIsAProxy* isa_proxy = new ::TIsAProxy(typeid(::TMVA::Experimental::SOFIE::Dim));
       static ::ROOT::TGenericClassInfo 
-         instance("TMVA::Experimental::SOFIE::Dim", "TMVA/SOFIE_common.hxx", 60,
+         instance("TMVA::Experimental::SOFIE::Dim", "TMVA/SOFIE_common.hxx", 63,
                   typeid(::TMVA::Experimental::SOFIE::Dim), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                   &TMVAcLcLExperimentalcLcLSOFIEcLcLDim_Dictionary, isa_proxy, 4,
                   sizeof(::TMVA::Experimental::SOFIE::Dim) );
@@ -186,7 +186,7 @@ namespace ROOT {
       ::TMVA::Experimental::SOFIE::InputTensorInfo *ptr = nullptr;
       static ::TVirtualIsAProxy* isa_proxy = new ::TIsAProxy(typeid(::TMVA::Experimental::SOFIE::InputTensorInfo));
       static ::ROOT::TGenericClassInfo 
-         instance("TMVA::Experimental::SOFIE::InputTensorInfo", "TMVA/SOFIE_common.hxx", 80,
+         instance("TMVA::Experimental::SOFIE::InputTensorInfo", "TMVA/SOFIE_common.hxx", 109,
                   typeid(::TMVA::Experimental::SOFIE::InputTensorInfo), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                   &TMVAcLcLExperimentalcLcLSOFIEcLcLInputTensorInfo_Dictionary, isa_proxy, 4,
                   sizeof(::TMVA::Experimental::SOFIE::InputTensorInfo) );
@@ -231,7 +231,7 @@ namespace ROOT {
       ::TMVA::Experimental::SOFIE::TensorInfo *ptr = nullptr;
       static ::TVirtualIsAProxy* isa_proxy = new ::TIsAProxy(typeid(::TMVA::Experimental::SOFIE::TensorInfo));
       static ::ROOT::TGenericClassInfo 
-         instance("TMVA::Experimental::SOFIE::TensorInfo", "TMVA/SOFIE_common.hxx", 85,
+         instance("TMVA::Experimental::SOFIE::TensorInfo", "TMVA/SOFIE_common.hxx", 114,
                   typeid(::TMVA::Experimental::SOFIE::TensorInfo), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                   &TMVAcLcLExperimentalcLcLSOFIEcLcLTensorInfo_Dictionary, isa_proxy, 4,
                   sizeof(::TMVA::Experimental::SOFIE::TensorInfo) );
@@ -276,7 +276,7 @@ namespace ROOT {
       ::TMVA::Experimental::SOFIE::InitializedTensor *ptr = nullptr;
       static ::TVirtualIsAProxy* isa_proxy = new ::TIsAProxy(typeid(::TMVA::Experimental::SOFIE::InitializedTensor));
       static ::ROOT::TGenericClassInfo 
-         instance("TMVA::Experimental::SOFIE::InitializedTensor", "TMVA/SOFIE_common.hxx", 193,
+         instance("TMVA::Experimental::SOFIE::InitializedTensor", "TMVA/SOFIE_common.hxx", 240,
                   typeid(::TMVA::Experimental::SOFIE::InitializedTensor), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                   &TMVAcLcLExperimentalcLcLSOFIEcLcLInitializedTensor_Dictionary, isa_proxy, 4,
                   sizeof(::TMVA::Experimental::SOFIE::InitializedTensor) );
@@ -321,7 +321,7 @@ namespace ROOT {
       ::TMVA::Experimental::SOFIE::GNN_Data *ptr = nullptr;
       static ::TVirtualIsAProxy* isa_proxy = new ::TIsAProxy(typeid(::TMVA::Experimental::SOFIE::GNN_Data));
       static ::ROOT::TGenericClassInfo 
-         instance("TMVA::Experimental::SOFIE::GNN_Data", "TMVA/SOFIE_common.hxx", 649,
+         instance("TMVA::Experimental::SOFIE::GNN_Data", "TMVA/SOFIE_common.hxx", 695,
                   typeid(::TMVA::Experimental::SOFIE::GNN_Data), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                   &TMVAcLcLExperimentalcLcLSOFIEcLcLGNN_Data_Dictionary, isa_proxy, 4,
                   sizeof(::TMVA::Experimental::SOFIE::GNN_Data) );
@@ -1132,6 +1132,71 @@ namespace ROOT {
    }
 } // end of namespace ROOT for class unordered_map<string,string>
 
+namespace ROOT {
+   static TClass *unordered_maplEstringcOpairlEvectorlETMVAcLcLExperimentalcLcLSOFIEcLcLDimgRcOboolgRsPgR_Dictionary();
+   static void unordered_maplEstringcOpairlEvectorlETMVAcLcLExperimentalcLcLSOFIEcLcLDimgRcOboolgRsPgR_TClassManip(TClass*);
+   static void *new_unordered_maplEstringcOpairlEvectorlETMVAcLcLExperimentalcLcLSOFIEcLcLDimgRcOboolgRsPgR(void *p = nullptr);
+   static void *newArray_unordered_maplEstringcOpairlEvectorlETMVAcLcLExperimentalcLcLSOFIEcLcLDimgRcOboolgRsPgR(Long_t size, void *p);
+   static void delete_unordered_maplEstringcOpairlEvectorlETMVAcLcLExperimentalcLcLSOFIEcLcLDimgRcOboolgRsPgR(void *p);
+   static void deleteArray_unordered_maplEstringcOpairlEvectorlETMVAcLcLExperimentalcLcLSOFIEcLcLDimgRcOboolgRsPgR(void *p);
+   static void destruct_unordered_maplEstringcOpairlEvectorlETMVAcLcLExperimentalcLcLSOFIEcLcLDimgRcOboolgRsPgR(void *p);
+
+   // Function generating the singleton type initializer
+   static TGenericClassInfo *GenerateInitInstanceLocal(const unordered_map<string,pair<vector<TMVA::Experimental::SOFIE::Dim>,bool> >*)
+   {
+      unordered_map<string,pair<vector<TMVA::Experimental::SOFIE::Dim>,bool> > *ptr = nullptr;
+      static ::TVirtualIsAProxy* isa_proxy = new ::TIsAProxy(typeid(unordered_map<string,pair<vector<TMVA::Experimental::SOFIE::Dim>,bool> >));
+      static ::ROOT::TGenericClassInfo 
+         instance("unordered_map<string,pair<vector<TMVA::Experimental::SOFIE::Dim>,bool> >", -2, "unordered_map", 112,
+                  typeid(unordered_map<string,pair<vector<TMVA::Experimental::SOFIE::Dim>,bool> >), ::ROOT::Internal::DefineBehavior(ptr, ptr),
+                  &unordered_maplEstringcOpairlEvectorlETMVAcLcLExperimentalcLcLSOFIEcLcLDimgRcOboolgRsPgR_Dictionary, isa_proxy, 0,
+                  sizeof(unordered_map<string,pair<vector<TMVA::Experimental::SOFIE::Dim>,bool> >) );
+      instance.SetNew(&new_unordered_maplEstringcOpairlEvectorlETMVAcLcLExperimentalcLcLSOFIEcLcLDimgRcOboolgRsPgR);
+      instance.SetNewArray(&newArray_unordered_maplEstringcOpairlEvectorlETMVAcLcLExperimentalcLcLSOFIEcLcLDimgRcOboolgRsPgR);
+      instance.SetDelete(&delete_unordered_maplEstringcOpairlEvectorlETMVAcLcLExperimentalcLcLSOFIEcLcLDimgRcOboolgRsPgR);
+      instance.SetDeleteArray(&deleteArray_unordered_maplEstringcOpairlEvectorlETMVAcLcLExperimentalcLcLSOFIEcLcLDimgRcOboolgRsPgR);
+      instance.SetDestructor(&destruct_unordered_maplEstringcOpairlEvectorlETMVAcLcLExperimentalcLcLSOFIEcLcLDimgRcOboolgRsPgR);
+      instance.AdoptCollectionProxyInfo(TCollectionProxyInfo::Generate(TCollectionProxyInfo::MapInsert< unordered_map<string,pair<vector<TMVA::Experimental::SOFIE::Dim>,bool> > >()));
+
+      instance.AdoptAlternate(::ROOT::AddClassAlternate("unordered_map<string,pair<vector<TMVA::Experimental::SOFIE::Dim>,bool> >","std::unordered_map<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> >, std::pair<std::vector<TMVA::Experimental::SOFIE::Dim, std::allocator<TMVA::Experimental::SOFIE::Dim> >, bool>, std::hash<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > >, std::equal_to<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > >, std::allocator<std::pair<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > const, std::pair<std::vector<TMVA::Experimental::SOFIE::Dim, std::allocator<TMVA::Experimental::SOFIE::Dim> >, bool> > > >"));
+      return &instance;
+   }
+   // Static variable to force the class initialization
+   static ::ROOT::TGenericClassInfo *_R__UNIQUE_DICT_(Init) = GenerateInitInstanceLocal(static_cast<const unordered_map<string,pair<vector<TMVA::Experimental::SOFIE::Dim>,bool> >*>(nullptr)); R__UseDummy(_R__UNIQUE_DICT_(Init));
+
+   // Dictionary for non-ClassDef classes
+   static TClass *unordered_maplEstringcOpairlEvectorlETMVAcLcLExperimentalcLcLSOFIEcLcLDimgRcOboolgRsPgR_Dictionary() {
+      TClass* theClass =::ROOT::GenerateInitInstanceLocal(static_cast<const unordered_map<string,pair<vector<TMVA::Experimental::SOFIE::Dim>,bool> >*>(nullptr))->GetClass();
+      unordered_maplEstringcOpairlEvectorlETMVAcLcLExperimentalcLcLSOFIEcLcLDimgRcOboolgRsPgR_TClassManip(theClass);
+   return theClass;
+   }
+
+   static void unordered_maplEstringcOpairlEvectorlETMVAcLcLExperimentalcLcLSOFIEcLcLDimgRcOboolgRsPgR_TClassManip(TClass* ){
+   }
+
+} // end of namespace ROOT
+
+namespace ROOT {
+   // Wrappers around operator new
+   static void *new_unordered_maplEstringcOpairlEvectorlETMVAcLcLExperimentalcLcLSOFIEcLcLDimgRcOboolgRsPgR(void *p) {
+      return  p ? ::new(static_cast<::ROOT::Internal::TOperatorNewHelper*>(p)) unordered_map<string,pair<vector<TMVA::Experimental::SOFIE::Dim>,bool> > : new unordered_map<string,pair<vector<TMVA::Experimental::SOFIE::Dim>,bool> >;
+   }
+   static void *newArray_unordered_maplEstringcOpairlEvectorlETMVAcLcLExperimentalcLcLSOFIEcLcLDimgRcOboolgRsPgR(Long_t nElements, void *p) {
+      return p ? ::new(static_cast<::ROOT::Internal::TOperatorNewHelper*>(p)) unordered_map<string,pair<vector<TMVA::Experimental::SOFIE::Dim>,bool> >[nElements] : new unordered_map<string,pair<vector<TMVA::Experimental::SOFIE::Dim>,bool> >[nElements];
+   }
+   // Wrapper around operator delete
+   static void delete_unordered_maplEstringcOpairlEvectorlETMVAcLcLExperimentalcLcLSOFIEcLcLDimgRcOboolgRsPgR(void *p) {
+      delete (static_cast<unordered_map<string,pair<vector<TMVA::Experimental::SOFIE::Dim>,bool> >*>(p));
+   }
+   static void deleteArray_unordered_maplEstringcOpairlEvectorlETMVAcLcLExperimentalcLcLSOFIEcLcLDimgRcOboolgRsPgR(void *p) {
+      delete [] (static_cast<unordered_map<string,pair<vector<TMVA::Experimental::SOFIE::Dim>,bool> >*>(p));
+   }
+   static void destruct_unordered_maplEstringcOpairlEvectorlETMVAcLcLExperimentalcLcLSOFIEcLcLDimgRcOboolgRsPgR(void *p) {
+      typedef unordered_map<string,pair<vector<TMVA::Experimental::SOFIE::Dim>,bool> > current_t;
+      (static_cast<current_t*>(p))->~current_t();
+   }
+} // end of namespace ROOT for class unordered_map<string,pair<vector<TMVA::Experimental::SOFIE::Dim>,bool> >
+
 namespace ROOT {
    static TClass *unordered_maplEstringcOTMVAcLcLExperimentalcLcLSOFIEcLcLTensorInfogR_Dictionary();
    static void unordered_maplEstringcOTMVAcLcLExperimentalcLcLSOFIEcLcLTensorInfogR_TClassManip(TClass*);
@@ -1461,25 +1526,27 @@ nullptr
     static const char* includePaths[] = {
 "/build/root/src/build-cuda/include",
 "/usr/include",
-"/usr/include",
 "/build/root/src/build-cuda/tmva/sofie",
 "/build/root/src/build-cuda/include/",
 nullptr
     };
     static const char* fwdDeclCode = R"DICTFWDDCLS(
 #line 1 "libROOTTMVASofie dictionary forward declarations' payload"
+
+#pragma diagnostic push
 #pragma clang diagnostic ignored "-Wkeyword-compat"
 #pragma clang diagnostic ignored "-Wignored-attributes"
 #pragma clang diagnostic ignored "-Wreturn-type-c-linkage"
 extern int __Cling_AutoLoading_Map;
-namespace TMVA{namespace Experimental{namespace SOFIE{struct __attribute__((annotate("$clingAutoload$TMVA/SOFIE_common.hxx")))  __attribute__((annotate("$clingAutoload$TMVA/OperatorList.hxx")))  Dim;}}}
-namespace TMVA{namespace Experimental{namespace SOFIE{struct __attribute__((annotate("$clingAutoload$TMVA/SOFIE_common.hxx")))  __attribute__((annotate("$clingAutoload$TMVA/OperatorList.hxx")))  InputTensorInfo;}}}
-namespace TMVA{namespace Experimental{namespace SOFIE{struct __attribute__((annotate("$clingAutoload$TMVA/SOFIE_common.hxx")))  __attribute__((annotate("$clingAutoload$TMVA/OperatorList.hxx")))  TensorInfo;}}}
-namespace TMVA{namespace Experimental{namespace SOFIE{class __attribute__((annotate("$clingAutoload$TMVA/SOFIE_common.hxx")))  __attribute__((annotate("$clingAutoload$TMVA/OperatorList.hxx")))  InitializedTensor;}}}
-namespace TMVA{namespace Experimental{namespace SOFIE{struct __attribute__((annotate("$clingAutoload$TMVA/SOFIE_common.hxx")))  __attribute__((annotate("$clingAutoload$TMVA/OperatorList.hxx")))  GNN_Data;}}}
-namespace TMVA{namespace Experimental{namespace SOFIE{class __attribute__((annotate("$clingAutoload$TMVA/ROperator.hxx")))  __attribute__((annotate("$clingAutoload$TMVA/OperatorList.hxx")))  ROperator;}}}
-namespace TMVA{namespace Experimental{namespace SOFIE{class __attribute__((annotate("$clingAutoload$TMVA/RModel_Base.hxx")))  __attribute__((annotate("$clingAutoload$TMVA/OperatorList.hxx")))  RModel_Base;}}}
-namespace TMVA{namespace Experimental{namespace SOFIE{class __attribute__((annotate("$clingAutoload$TMVA/RModel.hxx")))  __attribute__((annotate("$clingAutoload$TMVA/OperatorList.hxx")))  RModel;}}}
+namespace TMVA{namespace Experimental{namespace SOFIE{struct  __attribute__((annotate("$clingAutoload$TMVA/SOFIE_common.hxx")))  __attribute__((annotate("$clingAutoload$TMVA/OperatorList.hxx")))  Dim;}}}
+namespace TMVA{namespace Experimental{namespace SOFIE{struct  __attribute__((annotate("$clingAutoload$TMVA/SOFIE_common.hxx")))  __attribute__((annotate("$clingAutoload$TMVA/OperatorList.hxx")))  InputTensorInfo;}}}
+namespace TMVA{namespace Experimental{namespace SOFIE{struct  __attribute__((annotate("$clingAutoload$TMVA/SOFIE_common.hxx")))  __attribute__((annotate("$clingAutoload$TMVA/OperatorList.hxx")))  TensorInfo;}}}
+namespace TMVA{namespace Experimental{namespace SOFIE{class  __attribute__((annotate("$clingAutoload$TMVA/SOFIE_common.hxx")))  __attribute__((annotate("$clingAutoload$TMVA/OperatorList.hxx")))  InitializedTensor;}}}
+namespace TMVA{namespace Experimental{namespace SOFIE{struct  __attribute__((annotate("$clingAutoload$TMVA/SOFIE_common.hxx")))  __attribute__((annotate("$clingAutoload$TMVA/OperatorList.hxx")))  GNN_Data;}}}
+namespace TMVA{namespace Experimental{namespace SOFIE{class  __attribute__((annotate("$clingAutoload$TMVA/ROperator.hxx")))  __attribute__((annotate("$clingAutoload$TMVA/OperatorList.hxx")))  ROperator;}}}
+namespace TMVA{namespace Experimental{namespace SOFIE{class  __attribute__((annotate("$clingAutoload$TMVA/RModel_Base.hxx")))  __attribute__((annotate("$clingAutoload$TMVA/OperatorList.hxx")))  RModel_Base;}}}
+namespace TMVA{namespace Experimental{namespace SOFIE{class  __attribute__((annotate("$clingAutoload$TMVA/RModel.hxx")))  __attribute__((annotate("$clingAutoload$TMVA/OperatorList.hxx")))  RModel;}}}
+#pragma diagnostic pop
 )DICTFWDDCLS";
     static const char* payloadCode = R"DICTPAYLOAD(
 #line 1 "libROOTTMVASofie dictionary payload"
@@ -1490,6 +1557,9 @@ namespace TMVA{namespace Experimental{namespace SOFIE{class __attribute__((annot
 #ifndef ROOT_SUPPORT_CLAD
   #define ROOT_SUPPORT_CLAD 1
 #endif
+#ifndef R__DUMMY_CXX_STANDARD_17
+  #define R__DUMMY_CXX_STANDARD_17 1
+#endif
 
 #define _BACKWARD_BACKWARD_WARNING_H
 // Inline headers
