@@ -9,9 +9,6 @@
 #include <complex>
 #include <string>
 
-// ROOT
-#include "ROOT/RStringView.hxx"
-#include "TString.h"
 
 namespace CPyCppyy {
 
@@ -20,36 +17,36 @@ namespace {
 #define CPPYY_DECLARE_BASIC_CONVERTER(name)                                  \
 class name##Converter : public Converter {                                   \
 public:                                                                      \
-    virtual bool SetArg(PyObject*, Parameter&, CallContext* = nullptr);      \
-    virtual PyObject* FromMemory(void*);                                     \
-    virtual bool ToMemory(PyObject*, void*, PyObject* = nullptr);            \
+    bool SetArg(PyObject*, Parameter&, CallContext* = nullptr) override;     \
+    PyObject* FromMemory(void*) override;                                    \
+    bool ToMemory(PyObject*, void*, PyObject* = nullptr) override;           \
 };                                                                           \
                                                                              \
 class Const##name##RefConverter : public Converter {                         \
 public:                                                                      \
-    virtual bool SetArg(PyObject*, Parameter&, CallContext* = nullptr);      \
-    virtual PyObject* FromMemory(void*);                                     \
+    bool SetArg(PyObject*, Parameter&, CallContext* = nullptr) override;     \
+    PyObject* FromMemory(void*) override;                                    \
 }
 
 
 #define CPPYY_DECLARE_BASIC_CONVERTER2(name, base)                           \
 class name##Converter : public base##Converter {                             \
 public:                                                                      \
-    virtual PyObject* FromMemory(void*);                                     \
-    virtual bool ToMemory(PyObject*, void*, PyObject* = nullptr);            \
+    PyObject* FromMemory(void*) override;                                    \
+    bool ToMemory(PyObject*, void*, PyObject* = nullptr) override;           \
 };                                                                           \
                                                                              \
 class Const##name##RefConverter : public Converter {                         \
 public:                                                                      \
-    virtual bool SetArg(PyObject*, Parameter&, CallContext* = nullptr);      \
-    virtual PyObject* FromMemory(void*);                                     \
+    bool SetArg(PyObject*, Parameter&, CallContext* = nullptr) override;     \
+    PyObject* FromMemory(void*) override;                                    \
 }
 
 #define CPPYY_DECLARE_REFCONVERTER(name)                                     \
 class name##RefConverter : public Converter {                                \
 public:                                                                      \
-    virtual bool SetArg(PyObject*, Parameter&, CallContext* = nullptr);      \
-    virtual PyObject* FromMemory(void*);                                     \
+    bool SetArg(PyObject*, Parameter&, CallContext* = nullptr) override;     \
+    PyObject* FromMemory(void*) override;                                    \
 };
 
 #define CPPYY_DECLARE_ARRAY_CONVERTER(name)                                  \
@@ -58,10 +55,10 @@ public:                                                                      \
     name##ArrayConverter(cdims_t dims);                                      \
     name##ArrayConverter(const name##ArrayConverter&) = delete;              \
     name##ArrayConverter& operator=(const name##ArrayConverter&) = delete;   \
-    virtual bool SetArg(PyObject*, Parameter&, CallContext* = nullptr);      \
-    virtual PyObject* FromMemory(void*);                                     \
-    virtual bool ToMemory(PyObject*, void*, PyObject* = nullptr);            \
-    virtual bool HasState() { return true; }                                 \
+    bool SetArg(PyObject*, Parameter&, CallContext* = nullptr) override;     \
+    PyObject* FromMemory(void*) override;                                    \
+    bool ToMemory(PyObject*, void*, PyObject* = nullptr) override;           \
+    bool HasState() override { return true; }                                \
 protected:                                                                   \
     dims_t fShape;                                                           \
     bool fIsFixed;                                                           \
@@ -75,13 +72,13 @@ CPPYY_DECLARE_BASIC_CONVERTER(Char);
 class SCharAsIntConverter : public CharConverter {
 public:
     using CharConverter::CharConverter;
-    virtual PyObject* FromMemory(void*);
+    PyObject* FromMemory(void*) override;
 };
 CPPYY_DECLARE_BASIC_CONVERTER(UChar);
 class UCharAsIntConverter : public UCharConverter {
 public:
     using UCharConverter::UCharConverter;
-    virtual PyObject* FromMemory(void*);
+    PyObject* FromMemory(void*) override;
 };
 CPPYY_DECLARE_BASIC_CONVERTER(WChar);
 CPPYY_DECLARE_BASIC_CONVERTER(Char16);
@@ -130,7 +127,7 @@ CPPYY_DECLARE_REFCONVERTER(LDouble);
 
 class VoidConverter : public Converter {
 public:
-    virtual bool SetArg(PyObject*, Parameter&, CallContext* = nullptr);
+    bool SetArg(PyObject*, Parameter&, CallContext* = nullptr) override;
 };
 
 class CStringConverter : public Converter {
@@ -138,10 +135,10 @@ public:
     CStringConverter(std::string::size_type maxSize = std::string::npos) : fMaxSize(maxSize) {}
 
 public:
-    virtual bool SetArg(PyObject*, Parameter&, CallContext* = nullptr);
-    virtual PyObject* FromMemory(void* address);
-    virtual bool ToMemory(PyObject* value, void* address, PyObject* = nullptr);
-    virtual bool HasState() { return true; }
+    bool SetArg(PyObject*, Parameter&, CallContext* = nullptr) override;
+    PyObject* FromMemory(void* address) override;
+    bool ToMemory(PyObject* value, void* address, PyObject* = nullptr) override;
+    bool HasState() override { return true; }
 
 protected:
     std::string fBuffer;
@@ -153,8 +150,8 @@ public:
     using CStringConverter::CStringConverter;
 
 public:
-    virtual bool SetArg(PyObject*, Parameter&, CallContext* = nullptr);
-    virtual PyObject* FromMemory(void* address);
+    bool SetArg(PyObject*, Parameter&, CallContext* = nullptr) override;
+    PyObject* FromMemory(void* address) override;
 };
 
 class WCStringConverter : public Converter {
@@ -166,10 +163,10 @@ public:
     virtual ~WCStringConverter() { free(fBuffer); }
 
 public:
-    virtual bool SetArg(PyObject*, Parameter&, CallContext* = nullptr);
-    virtual PyObject* FromMemory(void* address);
-    virtual bool ToMemory(PyObject* value, void* address, PyObject* = nullptr);
-    virtual bool HasState() { return true; }
+    bool SetArg(PyObject*, Parameter&, CallContext* = nullptr) override;
+    PyObject* FromMemory(void* address) override;
+    bool ToMemory(PyObject* value, void* address, PyObject* = nullptr) override;
+    bool HasState() override { return true; }
 
 protected:
     wchar_t* fBuffer;
@@ -185,10 +182,10 @@ public:
     virtual ~CString16Converter() { free(fBuffer); }
 
 public:
-    virtual bool SetArg(PyObject*, Parameter&, CallContext* = nullptr);
-    virtual PyObject* FromMemory(void* address);
-    virtual bool ToMemory(PyObject* value, void* address, PyObject* = nullptr);
-    virtual bool HasState() { return true; }
+    bool SetArg(PyObject*, Parameter&, CallContext* = nullptr) override;
+    PyObject* FromMemory(void* address) override;
+    bool ToMemory(PyObject* value, void* address, PyObject* = nullptr) override;
+    bool HasState() override { return true; }
 
 protected:
     char16_t* fBuffer;
@@ -204,10 +201,10 @@ public:
     virtual ~CString32Converter() { free(fBuffer); }
 
 public:
-    virtual bool SetArg(PyObject*, Parameter&, CallContext* = nullptr);
-    virtual PyObject* FromMemory(void* address);
-    virtual bool ToMemory(PyObject* value, void* address, PyObject* = nullptr);
-    virtual bool HasState() { return true; }
+    bool SetArg(PyObject*, Parameter&, CallContext* = nullptr) override;
+    PyObject* FromMemory(void* address) override;
+    bool ToMemory(PyObject* value, void* address, PyObject* = nullptr) override;
+    bool HasState() override { return true; }
 
 protected:
     char32_t* fBuffer;
@@ -218,9 +215,7 @@ protected:
 CPPYY_DECLARE_ARRAY_CONVERTER(Bool);
 CPPYY_DECLARE_ARRAY_CONVERTER(SChar);
 CPPYY_DECLARE_ARRAY_CONVERTER(UChar);
-#if (__cplusplus > 201402L) || (defined(_MSC_VER) && _MSVC_LANG > 201402L)
 CPPYY_DECLARE_ARRAY_CONVERTER(Byte);
-#endif
 CPPYY_DECLARE_ARRAY_CONVERTER(Int8);
 CPPYY_DECLARE_ARRAY_CONVERTER(Int16);
 CPPYY_DECLARE_ARRAY_CONVERTER(Int32);
@@ -247,9 +242,9 @@ public:
         fIsFixed = fixed;    // overrides SCharArrayConverter decision
     }
     using SCharArrayConverter::SCharArrayConverter;
-    virtual bool SetArg(PyObject*, Parameter&, CallContext* = nullptr);
-    virtual PyObject* FromMemory(void* address);
-    virtual bool ToMemory(PyObject*, void*, PyObject* = nullptr);
+    bool SetArg(PyObject*, Parameter&, CallContext* = nullptr) override;
+    PyObject* FromMemory(void* address) override;
+    bool ToMemory(PyObject*, void*, PyObject* = nullptr) override;
 
 private:
     std::vector<const char*> fBuffer;
@@ -258,21 +253,21 @@ private:
 class NonConstCStringArrayConverter : public CStringArrayConverter {
 public:
     using CStringArrayConverter::CStringArrayConverter;
-    virtual PyObject* FromMemory(void* address);
+    PyObject* FromMemory(void* address) override;
 };
 
 // converters for special cases
 class NullptrConverter : public Converter {
 public:
-    virtual bool SetArg(PyObject*, Parameter&, CallContext* = nullptr);
+    bool SetArg(PyObject*, Parameter&, CallContext* = nullptr) override;
 };
 
 class InstanceConverter : public StrictInstancePtrConverter {
 public:
     using StrictInstancePtrConverter::StrictInstancePtrConverter;
-    virtual bool SetArg(PyObject*, Parameter&, CallContext* = nullptr);
-    virtual PyObject* FromMemory(void*);
-    virtual bool ToMemory(PyObject*, void*, PyObject* = nullptr);
+    bool SetArg(PyObject*, Parameter&, CallContext* = nullptr) override;
+    PyObject* FromMemory(void*) override;
+    bool ToMemory(PyObject*, void*, PyObject* = nullptr) override;
 };
 
 class InstanceRefConverter : public Converter  {
@@ -281,9 +276,9 @@ public:
         fClass(klass), fIsConst(isConst) {}
 
 public:
-    virtual bool SetArg(PyObject*, Parameter&, CallContext* = nullptr);
-    virtual PyObject* FromMemory(void* address);
-    virtual bool HasState() { return true; }
+    bool SetArg(PyObject*, Parameter&, CallContext* = nullptr) override;
+    PyObject* FromMemory(void* address) override;
+    bool HasState() override { return true; }
 
 protected:
     Cppyy::TCppType_t fClass;
@@ -293,7 +288,7 @@ protected:
 class InstanceMoveConverter : public InstanceRefConverter  {
 public:
     InstanceMoveConverter(Cppyy::TCppType_t klass) : InstanceRefConverter(klass, true) {}
-    virtual bool SetArg(PyObject*, Parameter&, CallContext* = nullptr);
+    bool SetArg(PyObject*, Parameter&, CallContext* = nullptr) override;
 };
 
 template <bool ISREFERENCE>
@@ -302,9 +297,9 @@ public:
     using InstancePtrConverter::InstancePtrConverter;
 
 public:
-    virtual bool SetArg(PyObject*, Parameter&, CallContext* = nullptr);
-    virtual PyObject* FromMemory(void* address);
-    virtual bool ToMemory(PyObject* value, void* address, PyObject* = nullptr);
+    bool SetArg(PyObject*, Parameter&, CallContext* = nullptr) override;
+    PyObject* FromMemory(void* address) override;
+    bool ToMemory(PyObject* value, void* address, PyObject* = nullptr) override;
 };
 
 class InstanceArrayConverter : public InstancePtrConverter<false> {
@@ -315,9 +310,9 @@ public:
     InstanceArrayConverter& operator=(const InstanceArrayConverter&) = delete;
 
 public:
-    virtual bool SetArg(PyObject*, Parameter&, CallContext* = nullptr);
-    virtual PyObject* FromMemory(void* address);
-    virtual bool ToMemory(PyObject* value, void* address, PyObject* = nullptr);
+    bool SetArg(PyObject*, Parameter&, CallContext* = nullptr) override;
+    PyObject* FromMemory(void* address) override;
+    bool ToMemory(PyObject* value, void* address, PyObject* = nullptr) override;
 
 protected:
     dims_t fShape;
@@ -329,10 +324,10 @@ public:
     ComplexDConverter(bool keepControl = false);
 
 public:
-    virtual bool SetArg(PyObject*, Parameter&, CallContext* = nullptr);
-    virtual PyObject* FromMemory(void* address);
-    virtual bool ToMemory(PyObject* value, void* address, PyObject* = nullptr);
-    virtual bool HasState() { return true; }
+    bool SetArg(PyObject*, Parameter&, CallContext* = nullptr) override;
+    PyObject* FromMemory(void* address) override;
+    bool ToMemory(PyObject* value, void* address, PyObject* = nullptr) override;
+    bool HasState() override { return true; }
 
 private:
     std::complex<double> fBuffer;
@@ -343,14 +338,14 @@ private:
 // they come in a bazillion different guises, so just do whatever
 class STLIteratorConverter : public Converter {
 public:
-    virtual bool SetArg(PyObject*, Parameter&, CallContext* = nullptr);
+    bool SetArg(PyObject*, Parameter&, CallContext* = nullptr) override;
 };
 // -- END CLING WORKAROUND
 
 
 class VoidPtrRefConverter : public Converter {
 public:
-    virtual bool SetArg(PyObject*, Parameter&, CallContext* = nullptr);
+    bool SetArg(PyObject*, Parameter&, CallContext* = nullptr) override;
 };
 
 class VoidPtrPtrConverter : public Converter {
@@ -358,9 +353,9 @@ public:
     VoidPtrPtrConverter(cdims_t dims);
 
 public:
-    virtual bool SetArg(PyObject*, Parameter&, CallContext* = nullptr);
-    virtual PyObject* FromMemory(void* address);
-    virtual bool HasState() { return true; }
+    bool SetArg(PyObject*, Parameter&, CallContext* = nullptr) override;
+    PyObject* FromMemory(void* address) override;
+    bool HasState() override { return true; }
 
 protected:
     dims_t fShape;
@@ -376,28 +371,25 @@ public:                                                                      \
     name##Converter(bool keepControl = true);                                \
                                                                              \
 public:                                                                      \
-    virtual bool SetArg(PyObject*, Parameter&, CallContext* = nullptr);      \
-    virtual PyObject* FromMemory(void* address);                             \
-    virtual bool ToMemory(PyObject*, void*, PyObject* = nullptr);            \
-    virtual bool HasState() { return true; }                                 \
+    bool SetArg(PyObject*, Parameter&, CallContext* = nullptr) override;     \
+    PyObject* FromMemory(void* address) override;                            \
+    bool ToMemory(PyObject*, void*, PyObject* = nullptr) override;           \
+    bool HasState() override { return true; }                                \
                                                                              \
 protected:                                                                   \
     strtype fBuffer;                                                         \
 }
 
-CPPYY_DECLARE_STRING_CONVERTER(TString, TString);
 CPPYY_DECLARE_STRING_CONVERTER(STLString, std::string);
 CPPYY_DECLARE_STRING_CONVERTER(STLWString, std::wstring);
-#if (__cplusplus > 201402L) || (defined(_MSC_VER) && _MSVC_LANG > 201402L)
 CPPYY_DECLARE_STRING_CONVERTER(STLStringView, std::string_view);
-#endif
 
 class STLStringMoveConverter : public STLStringConverter {
 public:
     using STLStringConverter::STLStringConverter;
 
 public:
-    virtual bool SetArg(PyObject*, Parameter&, CallContext* = nullptr);
+    bool SetArg(PyObject*, Parameter&, CallContext* = nullptr) override;
 };
 
 
@@ -408,10 +400,10 @@ public:
         fRetType(ret), fSignature(sig) {}
 
 public:
-    virtual bool SetArg(PyObject*, Parameter&, CallContext* = nullptr);
-    virtual PyObject* FromMemory(void* address);
-    virtual bool ToMemory(PyObject*, void*, PyObject* = nullptr);
-    virtual bool HasState() { return true; }
+    bool SetArg(PyObject*, Parameter&, CallContext* = nullptr) override;
+    PyObject* FromMemory(void* address) override;
+    bool ToMemory(PyObject*, void*, PyObject* = nullptr) override;
+    bool HasState() override { return true; }
 
 protected:
     std::string fRetType;
@@ -428,9 +420,9 @@ public:
     virtual ~StdFunctionConverter() { delete fConverter; }
 
 public:
-    virtual bool SetArg(PyObject*, Parameter&, CallContext* = nullptr);
-    virtual PyObject* FromMemory(void* address);
-    virtual bool ToMemory(PyObject* value, void* address, PyObject* = nullptr);
+    bool SetArg(PyObject*, Parameter&, CallContext* = nullptr) override;
+    PyObject* FromMemory(void* address) override;
+    bool ToMemory(PyObject* value, void* address, PyObject* = nullptr) override;
 
 protected:
     Converter* fConverter;
@@ -448,10 +440,10 @@ public:
           fKeepControl(keepControl), fIsRef(isRef) {}
 
 public:
-    virtual bool SetArg(PyObject*, Parameter&, CallContext* = nullptr);
-    virtual PyObject* FromMemory(void* address);
-    virtual bool ToMemory(PyObject*, void*, PyObject* = nullptr);
-    virtual bool HasState() { return true; }
+    bool SetArg(PyObject*, Parameter&, CallContext* = nullptr) override;
+    PyObject* FromMemory(void* address) override;
+    bool ToMemory(PyObject*, void*, PyObject* = nullptr) override;
+    bool HasState() override { return true; }
 
 protected:
     virtual bool GetAddressSpecialCase(PyObject*, void*&) { return false; }
@@ -472,8 +464,8 @@ public:
     virtual ~InitializerListConverter();
 
 public:
-    virtual bool SetArg(PyObject*, Parameter&, CallContext* = nullptr);
-    virtual bool HasState() { return true; }
+    bool SetArg(PyObject*, Parameter&, CallContext* = nullptr) override;
+    bool HasState() override { return true; }
 
 protected:
     void Clear();
@@ -490,7 +482,7 @@ protected:
 // raising converter to take out overloads
 class NotImplementedConverter : public Converter {
 public:
-    virtual bool SetArg(PyObject*, Parameter&, CallContext* = nullptr);
+    bool SetArg(PyObject*, Parameter&, CallContext* = nullptr) override;
 };
 
 } // unnamed namespace
