@@ -47,7 +47,7 @@
 #include "snprintf.h"
 
 #ifdef R__UNIX
-#include <signal.h>
+#include <csignal>
 #include <unistd.h>
 #endif
 
@@ -134,7 +134,6 @@ Bool_t TTermInputHandler::Notify()
 }
 
 
-ClassImp(TRint);
 
 
 namespace {
@@ -181,7 +180,7 @@ TRint::TRint(const char *appClassName, Int_t *argc, char **argv, void *options,
          std::cerr << "root: unrecognized option '" << argv[n] << "'\n";
       }
       std::cerr << "Try 'root --help' for more information.\n";
-      TApplication::Terminate(0);
+      TApplication::Terminate(2);
    }
 
    fNcmd          = 0;
@@ -195,11 +194,16 @@ TRint::TRint(const char *appClassName, Int_t *argc, char **argv, void *options,
       PrintLogo(lite);
    }
 
-   // Explicitly load libMathCore it cannot be auto-loaded it when using one
-   // of its freestanding functions. Once functions can trigger autoloading we
-   // can get rid of this.
+#ifndef R__USE_CXXMODULES
+   // When modules are not used, and therefore rootmaps, freestanding functions 
+   // cannot trigger autoloading. Therefore, given the widespread usage of the 
+   // freestanding functions in MathCore, we  load the library explicitly.
+   // When modules are used to condense the reflection information, this manual
+   // loading is not needed, and it can be skipped in order to save time and 
+   // memory when starting the ROOT prompt.
    if (!gClassTable->GetDict("TRandom"))
       gSystem->Load("libMathCore");
+#endif
 
    if (!gInterpreter->HasPCMForLibrary("std")) {
       // Load some frequently used includes
@@ -493,7 +497,6 @@ void TRint::Run(Bool_t retrn)
    }
 
    if (QuitOpt()) {
-      printf("\n");
       if (retrn) return;
       Terminate(fCaughtSignal != -1 ? fCaughtSignal + 128 : 0);
    }
@@ -539,8 +542,8 @@ void TRint::PrintLogo(Bool_t lite)
                                             gROOT->GetGitBranch(),
                                             gROOT->GetGitCommit()));
       }
-      lines.emplace_back(TString::Format("With %s %%s",
-                                         gSystem->GetBuildCompilerVersionStr()));
+      lines.emplace_back(TString::Format("With %s std%ld %%s",
+                                         gSystem->GetBuildCompilerVersionStr(), __cplusplus));
       lines.emplace_back(TString("Try '.help'/'.?', '.demo', '.license', '.credits', '.quit'/'.q'%s"));
 
       // Find the longest line and its length:
