@@ -16,6 +16,7 @@
 #include <ROOT/RError.hxx>
 #include <ROOT/RMiniFile.hxx>
 #include <ROOT/RRawFile.hxx>
+#include <ROOT/RNTupleUtils.hxx>
 #include <ROOT/RNTupleZip.hxx>
 #include <ROOT/RNTupleSerialize.hxx>
 #include <ROOT/RNTupleWriteOptions.hxx>
@@ -28,7 +29,7 @@
 #include <TKey.h>
 #include <TObjString.h>
 #include <TUUID.h>
-#include <TVirtualStreamerInfo.h>
+#include <TStreamerInfo.h>
 
 #include <xxhash.h>
 
@@ -403,6 +404,13 @@ struct RTFHeader {
       }
    }
 
+   std::uint64_t GetNbytesInfo() const
+   {
+      if (IsBigFile())
+         return fInfoLong.fNbytesInfo;
+      return fInfoShort.fNbytesInfo;
+   }
+
    void SetNbytesInfo(std::uint32_t value)
    {
       if (IsBigFile()) {
@@ -714,6 +722,50 @@ std::uint64_t ROOT::Internal::RMiniFileReader::SearchInDirectory(std::uint64_t &
    return 0;
 }
 
+void ROOT::Internal::RMiniFileReader::LoadStreamerInfo()
+{
+   RTFHeader fileHeader;
+   ReadBuffer(&fileHeader, sizeof(fileHeader), 0);
+
+   const std::uint64_t seekKeyInfo = fileHeader.GetSeekInfo();
+
+   RTFKey key;
+   ReadBuffer(&key, sizeof(key), seekKeyInfo);
+
+   const std::uint64_t nbytesInfo = fileHeader.GetNbytesInfo() - key.fKeyLen;
+   const std::uint64_t seekInfo = seekKeyInfo + key.fKeyLen;
+   const std::uint32_t uncompLenInfo = key.fObjLen;
+   auto streamerInfo = MakeUninitArray<char>(uncompLenInfo);
+   if (nbytesInfo == uncompLenInfo) {
+      // Uncompressed
+      ReadBuffer(streamerInfo.get(), nbytesInfo, seekInfo);
+   } else {
+      auto buffer = MakeUninitArray<std::byte>(nbytesInfo);
+      ReadBuffer(buffer.get(), nbytesInfo, seekInfo);
+      RNTupleDecompressor::Unzip(buffer.get(), nbytesInfo, uncompLenInfo, streamerInfo.get());
+   }
+
+   TBufferFile buffer(TBuffer::kRead, uncompLenInfo, streamerInfo.release());
+   // This is necessary to allow the "class tags" inside the StreamerInfo list to refer to the proper offset into
+   // the buffer. Normally TFile loads the StreamerInfo via TKey::ReadObjWithBuffer, whose buffer also includes the
+   // key itself. Since we dealt with the key above already, we are only passing the payload to TBufferFile so offsets
+   // need to be patched up.
+   buffer.SetBufferDisplacement(key.fKeyLen);
+   TList streamerInfoList;
+   streamerInfoList.Streamer(buffer);
+   TObjLink *lnk = streamerInfoList.FirstLink();
+   while (lnk) {
+      auto obj = lnk->GetObject();
+      // NOTE: the last element of the streamer info list may be a TList with the IO customization rules, so we need
+      // to check before static casting.
+      if (obj->IsA() == TStreamerInfo::Class()) {
+         auto info = static_cast<TStreamerInfo *>(obj);
+         info->BuildCheck();
+      }
+      lnk = lnk->Next();
+   }
+}
+
 ROOT::RResult<ROOT::RNTuple> ROOT::Internal::RMiniFileReader::GetNTupleProper(std::string_view ntuplePath)
 {
    RTFHeader fileHeader;
@@ -763,28 +815,38 @@ ROOT::RResult<ROOT::RNTuple> ROOT::Internal::RMiniFileReader::GetNTupleProper(st
    if (key.fObjLen < kMinNTupleSize) {
       return R__FAIL("invalid anchor size: " + std::to_string(key.fObjLen) + " < " + std::to_string(sizeof(RTFNTuple)));
    }
+
+   const auto objNbytes = key.GetSize() - key.fKeyLen;
+   auto res = GetNTupleProperAtOffset(offset, objNbytes, key.fObjLen);
+   return res;
+}
+
+ROOT::RResult<ROOT::RNTuple> ROOT::Internal::RMiniFileReader::GetNTupleProperAtOffset(std::uint64_t payloadOffset,
+                                                                                      std::uint64_t compSize,
+                                                                                      std::uint64_t uncompLen)
+{
    // The object length can be smaller than the size of RTFNTuple if it comes from a past RNTuple class version,
    // or larger than it if it comes from a future RNTuple class version.
-   auto bufAnchor = MakeUninitArray<unsigned char>(std::max<size_t>(key.fObjLen, sizeof(RTFNTuple)));
+   auto bufAnchor = MakeUninitArray<unsigned char>(std::max<size_t>(uncompLen, sizeof(RTFNTuple)));
    RTFNTuple *ntuple = new (bufAnchor.get()) RTFNTuple;
 
-   auto objNbytes = key.GetSize() - key.fKeyLen;
-   ReadBuffer(ntuple, objNbytes, offset);
-   if (objNbytes != key.fObjLen) {
-      // Decompress into a temporary buffer
-      auto unzipBuf = MakeUninitArray<unsigned char>(key.fObjLen);
-      RNTupleDecompressor::Unzip(bufAnchor.get(), objNbytes, key.fObjLen, unzipBuf.get());
-      // Then copy back to bufAnchor
-      memcpy(bufAnchor.get(), unzipBuf.get(), key.fObjLen);
+   if (compSize != uncompLen) {
+      // Read into a temporary buffer
+      auto unzipBuf = MakeUninitArray<unsigned char>(std::max<size_t>(uncompLen, sizeof(RTFNTuple)));
+      ReadBuffer(unzipBuf.get(), compSize, payloadOffset);
+      // Unzip into the final buffer
+      RNTupleDecompressor::Unzip(unzipBuf.get(), compSize, uncompLen, ntuple);
+   } else {
+      ReadBuffer(ntuple, compSize, payloadOffset);
    }
 
    // We require that future class versions only append members and store the checksum in the last 8 bytes
    // Checksum calculation: strip byte count, class version, fChecksum member
-   auto lenCkData = key.fObjLen - ntuple->GetOffsetCkData() - sizeof(uint64_t);
-   auto ckCalc = XXH3_64bits(ntuple->GetPtrCkData(), lenCkData);
+   const auto lenCkData = uncompLen - ntuple->GetOffsetCkData() - sizeof(uint64_t);
+   const auto ckCalc = XXH3_64bits(ntuple->GetPtrCkData(), lenCkData);
    uint64_t ckOnDisk;
 
-   RUInt64BE *ckOnDiskPtr = reinterpret_cast<RUInt64BE *>(bufAnchor.get() + key.fObjLen - sizeof(uint64_t));
+   RUInt64BE *ckOnDiskPtr = reinterpret_cast<RUInt64BE *>(bufAnchor.get() + uncompLen - sizeof(uint64_t));
    ckOnDisk = static_cast<uint64_t>(*ckOnDiskPtr);
    if (ckCalc != ckOnDisk) {
       return R__FAIL("RNTuple anchor checksum mismatch");
